==> sight_21.0.0.orig.tar.gz: sight-21.0.0/libs/ui/base/dialog/IPulseProgressDialog.cpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2021 IRCAD France
 * Copyright (C) 2012-2021 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#include "ui/base/dialog/IPulseProgressDialog.hpp"

namespace sight::ui::base
{

namespace dialog
{

const IPulseProgressDialog::FactoryRegistryKeyType IPulseProgressDialog::REGISTRY_KEY =
    "::ui::base::dialog::PulseProgressDialog";

IPulseProgressDialog::IPulseProgressDialog()
{
}

//-----------------------------------------------------------------------------

IPulseProgressDialog::~IPulseProgressDialog()
{
}

//-----------------------------------------------------------------------------

void IPulseProgressDialog::setStuff(Stuff stuff)
{
    m_stuff = stuff;
}

//-----------------------------------------------------------------------------

void IPulseProgressDialog::setFrequence(MilliSecond frequence)
{
    m_frequence = frequence;
}

//-----------------------------------------------------------------------------

} //namespace dialog

} // namespace sight::ui::base

==> sight_23.1.0.orig.tar.gz: sight-23.1.0/libs/ui/base/dialog/IPulseProgressDialog.cpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2022 IRCAD France
 * Copyright (C) 2012-2021 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#include "ui/base/dialog/IPulseProgressDialog.hpp"

namespace sight::ui::base::dialog
{

const IPulseProgressDialog::FactoryRegistryKeyType IPulseProgressDialog::REGISTRY_KEY =
    "::ui::base::dialog::PulseProgressDialog";

IPulseProgressDialog::IPulseProgressDialog()
= default;

//-----------------------------------------------------------------------------

IPulseProgressDialog::~IPulseProgressDialog()
= default;

//-----------------------------------------------------------------------------

void IPulseProgressDialog::setStuff(Stuff stuff)
{
    m_stuff = stuff;
}

//-----------------------------------------------------------------------------

void IPulseProgressDialog::setFrequence(MilliSecond frequence)
{
    m_frequence = frequence;
}

//-----------------------------------------------------------------------------

} // namespace sight::ui::base::dialog
